@@ -14,7 +14,9 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with flufl.password.  If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import absolute_import, unicode_literals
+"""Make secrets."""
+
+from __future__ import absolute_import, print_function, unicode_literals
 
 __metaclass__ = type
 __all__ = [
