@@ -19,7 +19,7 @@
 Represents passwords using RFC 2307 syntax (as best we can tell).
 """
 
-from __future__ import absolute_import, unicode_literals
+from __future__ import absolute_import, print_function, unicode_literals
 
 __metaclass__ = type
 __all__ = [
@@ -160,6 +160,14 @@ class SSHAPasswordScheme(PasswordScheme):
 
 
 
+def _bytes_of(array_obj):
+    # Avoid DeprecationWarnings in Python 3.
+    try:
+        return array_obj.tobytes()
+    except AttributeError:
+        return array_obj.tostring()
+
+
 # Basic algorithm given by Bob Fleck
 @register
 class PBKDF2PasswordScheme(PasswordScheme):
@@ -186,11 +194,11 @@ class PBKDF2PasswordScheme(PasswordScheme):
         T = U = array_of_signedints(prf.digest())
         while iterations:
             prf = h.copy()
-            prf.update(U.tostring())
+            prf.update(_bytes_of(U))
             U = array_of_signedints(prf.digest())
             T = array_of_signedints((t ^ u for t, u in zip(T, U)))
             iterations -= 1
-        return T.tostring()
+        return _bytes_of(T)
 
     @staticmethod
     def make_secret(password):
