@@ -17,7 +17,7 @@
 
 """Test harness for doctests."""
 
-from __future__ import absolute_import, unicode_literals
+from __future__ import absolute_import, print_function, unicode_literals
 
 __metaclass__ = type
 __all__ = [
@@ -73,6 +73,7 @@ def setup(testobj):
     # defined.
     try:
         testobj.globs['absolute_import'] = absolute_import
+        testobj.globs['print_function'] = print_function
         testobj.globs['unicode_literals'] = unicode_literals
     except NameError:
         pass
@@ -98,8 +99,3 @@ def additional_tests():
     atexit.register(cleanup_resources)
     return unittest.TestSuite((
         doctest.DocFileSuite(*doctest_files, **kwargs)))
-
-
-## def load_tests(loader, tests, pattern):
-##     """For `python -m unittest discover`."""
-##     return additional_tests()
